@@ -14,7 +14,7 @@ logging.basicConfig(format="%(message)s", level=logging.INFO)
 log = lambda message: logging.info(message)
 
 
-VERSION = "2022-09-26"
+VERSION = "2022-09-28"
 HELP = f"""
 trim reads from single or paired fastq files
 expect all sequences (reads and given adapters) to be 5' -> 3' oriented
@@ -197,7 +197,8 @@ def read_process(input_path, chunk_size, sync_queue_in, sync_queue_out, input_qu
             sync_queue_in.put([input_path, len(chunk), read_done])
             send_size, keep_going = sync_queue_out.get()
             chunk, keep_for_next = chunk[:send_size], chunk[send_size:]
-            input_queue.put(chunk)
+            if send_size:
+                input_queue.put(chunk)
     for _ in range(parallel):
         input_queue.put(None)
 
@@ -269,10 +270,10 @@ def trim_process(adapters, input_queues, input_lock, cut_5, cut_3, min_length, d
             for index, entries in enumerate(output_batch):
                 output_batch[index] = [entries[keep_index] for keep_index in keep_indexes]
         for index, (entries, gz_level) in enumerate(zip(output_batch, gz_levels)):
-            if not entries:
-                output_batch[index] = b""
-                continue
-            entries = "\n".join("\n".join(entry) for entry in entries).encode() + b"\n"
+            if entries:
+                entries = "\n".join("\n".join(entry) for entry in entries).encode() + b"\n"
+            else:
+                entries = b""
             if gz_level >= 0:
                 entries = gzip.compress(entries, compresslevel=gz_level)
             output_batch[index] = entries
